@@ -1,10 +1,17 @@
 import pytest
 import os
 import json
+from hypothesis import given, strategies as st
 
 from graphio.objects.nodeset import NodeSet
 
 
+@pytest.fixture(scope="session")
+def reusable_tmp_dir(tmpdir_factory):
+    fn = tmpdir_factory.mktemp("data")
+    return fn
+
+
 @pytest.fixture
 def small_nodeset() -> NodeSet:
     ns = NodeSet(['Test'], merge_keys=['uuid'])
@@ -27,7 +34,7 @@ def nodeset_multiple_labels():
 def nodeset_multiple_labels_multiple_merge_keys():
     ns = NodeSet(['Test', 'Foo', 'Bar'], merge_keys=['uuid', 'other'])
     for i in range(1000):
-        ns.add_node({'uuid': i})
+        ns.add_node({'uuid': i, 'other': i + 10})
 
     return ns
 
@@ -53,6 +60,33 @@ def test_nodeset_add_unique():
     assert len(ns.nodes) == 1
 
 
+def test_nodeset__estimate_type_of_property_values():
+    ns = NodeSet(['Test'], merge_keys=['uuid'])
+    for i in range(10):
+        ns.add_node({'uuid': i, 'key': 'value', 'foo': 20.5, 'changing': 4})
+    # change type for one property to make sure that str is set for inconsistent types
+    ns.add_node({'uuid': 1, 'key': 'value', 'foo': 20.5, 'changing': 30.4})
+
+    types = ns._estimate_type_of_property_values()
+    assert types['uuid'] == int
+    assert types['key'] == str
+    assert types['foo'] == float
+    assert types['changing'] == str
+
+
+class TestNodeSetInstances:
+
+    @given(labels=st.lists(st.text(), max_size=10),
+           merge_keys=st.lists(st.text(), max_size=10),
+           data=st.lists(st.dictionaries(keys=st.text(),
+                                         values=st.one_of(st.integers(), st.text(), st.booleans(), st.datetimes())))
+           )
+    def test_create_instance_add_nodes(self, labels, merge_keys, data):
+        ns = NodeSet(labels, merge_keys)
+        for i in data:
+            ns.add_node(i)
+
+
 class TestDefaultProps:
 
     def test_default_props(self):
@@ -259,7 +293,6 @@ class TestNodeSetMerge:
         for i in range(100):
             append_ns.add_node({'uuid': i, 'key': 'other_value'})
 
-
         append_ns.merge(graph)
 
         assert list(graph.run("MATCH (n:Test) where 'value' IN n.key RETURN count(n)"))[0][0] == 100
