@@ -95,6 +95,38 @@ def test_relationshipset_unique():
     assert len(rs.relationships) == 1
 
 
+def test_relationshipset_all_property_keys():
+    rs = RelationshipSet('TEST', ['Source'], ['Target'], ['uid'], ['name'])
+
+    random_keys = ['name', 'city', 'value', 'key']
+
+    for val in random_keys:
+        for i in range(20):
+            rel_props = {}
+            rel_props[val] = 'peter'
+
+            rs.add_relationship({'uid': 1}, {'name': 'peter'}, rel_props)
+
+    assert rs.all_property_keys() == set(random_keys)
+
+
+def test_relationshipset_estiamte_types():
+    rs = RelationshipSet('TEST', ['Source'], ['Target'], ['uid'], ['name', 'height', 'age'])
+
+    for i in range(20):
+        rs.add_relationship({'uid': 1}, {'name': 'peter', 'height': 20.5, 'age': 50},
+                            {'country': 'germany', 'weight': 70.4, 'number': 20})
+
+    start_node_property_types, rel_property_types, end_node_property_types = rs._estimate_type_of_property_values()
+    assert start_node_property_types['uid'] == int
+    assert end_node_property_types['name'] == str
+    assert end_node_property_types['height'] == float
+    assert end_node_property_types['age'] == int
+    assert rel_property_types['country'] == str
+    assert rel_property_types['weight'] == float
+    assert rel_property_types['number'] == int
+
+
 class TestDefaultProps:
 
     def test_default_props(self):
